Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFetcher ¶
func NewFetcher(funcs Funcs) *fetcher
Types ¶
type ContextKey ¶
type ContextKey string
ContextKey is a typed key for context values to avoid SA1029.
const FetchModeKey ContextKey = "fetchmode"
FetchModeKey is the context key used to indicate fetch-by-type mode.
type FetchResult ¶
Click to show internal directories.
Click to hide internal directories.